# Thak trs e 函式庫
[![PyPI version](https://badge.fury.io/py/thaktrs.svg)](https://badge.fury.io/py/thaktrs)
[![Build Status](https://travis-ci.org/twgo/Thak-trs.svg?branch=master)](https://travis-ci.org/twgo/Thak-trs)
[![Coverage Status](https://coveralls.io/repos/github/twgo/Thak-trs/badge.svg?branch=master)](https://coveralls.io/github/twgo/Thak-trs?branch=master)

```
python -m unittest
```
